"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.MapExecutor = void 0;
const StateTypeExecutor_1 = require("../StateTypeExecutor");
const StateMachineExecutor_1 = require("../../StateMachineExecutor");
const StateContext_1 = require("../../Context/StateContext");
const StateProcessor_1 = require("../../StateProcessor");
const StateMachine_1 = require("../../StateMachine/StateMachine");
const Logger_1 = require("../../utils/Logger");
class MapExecutor extends StateTypeExecutor_1.StateTypeExecutor {
    constructor() {
        super(...arguments);
        this.pendingStateMachineExecutions = {};
    }
    async execute(context, stateDefinition, inputJson) {
        const stateMachineDescription = {
            name: stateDefinition.Comment,
            definition: stateDefinition.Iterator,
        };
        const stateMachine = StateMachine_1.StateMachine.create(stateMachineDescription.name || '', stateMachineDescription);
        if (!inputJson) {
            throw new Error(`Undefined inputJson for state `);
        }
        const iterable = this.processInput(inputJson, stateDefinition, context);
        const output = [];
        await Promise.all(iterable.map(async (value, index) => {
            const tempContext = context.clone();
            tempContext.startMapItration(index, typeof value === 'string' ? value : JSON.stringify(value));
            const iterationInput = StateProcessor_1.StateProcessor.processParameters(inputJson, stateDefinition.Parameters, tempContext);
            const stateName = stateDefinition.Iterator.StartAt;
            const stateContext = StateContext_1.StateContext.create(stateName);
            tempContext.transitionTo(stateContext);
            const sme = new StateMachineExecutor_1.StateMachineExecutor(stateMachine, tempContext);
            const startAtState = stateDefinition.Iterator.States[stateDefinition.Iterator.StartAt];
            const execution = await sme.execute(startAtState, iterationInput);
            if (execution instanceof StateMachineExecutor_1.StateMachineExecutorError) {
                throw execution.error;
            }
            output.push(execution);
        }));
        return {
            Next: stateDefinition.Next,
            End: stateDefinition.End,
            json: JSON.stringify(output),
        };
    }
    processInput(json, stateDefinition, context) {
        this.logger.debug(`MapExecutor - processInput1 - ${json}`);
        const proccessedInputJson = StateProcessor_1.StateProcessor.processInputPath(json, stateDefinition.InputPath);
        const proccessedItemsJson = StateProcessor_1.StateProcessor.processItemsPath(proccessedInputJson, stateDefinition.ItemsPath);
        let processedItems;
        try {
            processedItems = JSON.parse(proccessedItemsJson);
        }
        catch (error) {
            this.logger.error(`MapExecutor.processInput: Could not parse JSON for state ${context.State.Name}: "${proccessedItemsJson}"`);
            throw error;
        }
        if (!Array.isArray(processedItems)) {
            this.logger.error('Processed input & items is not an array ' +
                `with InputPath: ${stateDefinition.InputPath} & ItemsPaths: ${stateDefinition.ItemsPath} and input: ${json}`);
            throw new Error('Input is not an array');
        }
        Logger_1.Logger.getInstance().debug('Finished processing Map input');
        Logger_1.Logger.getInstance().debug(JSON.stringify(processedItems));
        Logger_1.Logger.getInstance().debug(typeof processedItems[0]);
        return processedItems;
    }
}
exports.MapExecutor = MapExecutor;
